Select class
A selector component.
Constructors
-
Select({required String prompt, required List<
String> options, int initialIndex = 0}) - Constructs a Select component with the default theme.
-
Select.withTheme({required String prompt, required List<
String> options, required Theme theme, int initialIndex = 0}) - Constructs a Select component with the supplied theme.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialIndex → int
-
The index to be selected by default.
final
-
options
→ List<
String> -
The List of available String options to show
to the user.
final
- prompt → String
-
The prompt to be shown together with the user's input.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → Theme
-
The theme of the component.
final
Methods
-
createState(
) → _SelectState -
Creates a State for current component,
inspired by Flutter's
StatefulWidget.override -
disposeState(
State< Component> state) → void -
Disposes current state, to make the Context null and unusable
after the rendering is completely finished.
inherited
-
interact(
) → int -
Starts the rendering processs.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pipeState(
State< Component> state) → State<Component> -
Pipes the state after running
createStatein case of needing to handle the state from outside.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited