interact2
library
Classes
AsyncComponent <T extends dynamic >
A Component is an abstraction made with purpose
of writing clear/managed state and rendering for
various components this library will create.
AsyncInput
An input component.
BufferContext
Unlike a normal Context , BufferContext writes lines to a specified
StringBuffer and run a reload function on every line written.
Component <T extends dynamic >
A Component is an abstraction made with purpose
of writing clear/managed state and rendering for
various components this library will create.
Confirm
A confirm component.
Context
Context is used by Component and State to actually render
things to the console, and to act as a state store during rendering,
which will store things such as the number or renderings done and the
amount of lines used by a specific render, so that the State can
clear old lines and render new stuffs automatically.
Input
An input component.
MultiProgress
A shared context and handler for rendering multiple Progress bars.
MultiSelect
A multiple select or checkbox input component.
MultiSpinner
A shared context and handler for rendering multiple Spinner s.
Password
A password input component.
Progress
A progress bar component.
ProgressState
Handles a progress bar's state.
Select
A selector component.
Sort
A sortable list component.
Spinner
A spinner or a loading indicator component.
SpinnerState
Handles a Spinner 's state.
State <T extends Component >
Provides the structure and setState function.
Theme
The theme to be used by components.
ValidationError
The error message to be thrown from the Input component's
validator when there is an error.
Properties
reset
↔ void Function()
Resets the Terminal to default values.
getter/setter pair